@@ -449,6 +449,9 @@ atspi_state_type_get_type (void)
 			{ ATSPI_STATE_HAS_POPUP,
 			  "ATSPI_STATE_HAS_POPUP",
 			  "has-popup" },
+			{ ATSPI_STATE_READ_ONLY,
+			  "ATSPI_STATE_READ_ONLY",
+			  "read-only" },
 			{ ATSPI_STATE_LAST_DEFINED,
 			  "ATSPI_STATE_LAST_DEFINED",
 			  "last-defined" },
